pub struct UmaKeg {Show 14 fields
vm: &'static Vm,
size: NonZero<usize>,
rsize: usize,
pgoff: usize,
ppera: usize,
ipers: usize,
alloc: fn(&'static Vm, Alloc) -> (*mut u8, SlabFlags),
init: Option<fn()>,
max_pages: usize,
pages: usize,
pub(super) free: usize,
recurse: u32,
partial_slabs: VecDeque<NonNull<Slab>>,
flags: UmaFlags,
}Expand description
Implementation of uma_keg structure.
Fields
vm: &'static Vmsize: NonZero<usize>rsize: usizepgoff: usizeppera: usizeipers: usizealloc: fn(&'static Vm, Alloc) -> (*mut u8, SlabFlags)init: Option<fn()>max_pages: usizepages: usizefree: usizerecurse: u32partial_slabs: VecDeque<NonNull<Slab>>flags: UmaFlagsImplementations
Sourceimpl UmaKeg
impl UmaKeg
Sourcepub(super) fn new(
vm: &'static Vm,
size: NonZero<usize>,
align: usize,
init: Option<fn()>,
flags: UmaFlags,
) -> Self
pub(super) fn new( vm: &'static Vm, size: NonZero<usize>, align: usize, init: Option<fn()>, flags: UmaFlags, ) -> Self
align is the actual alignment minus one, which mean if you want each item to be 8
bytes alignment this value will be 7.
See keg_ctor on the Orbis for a reference.
Reference offsets
| Version | Offset |
|---|---|
| PS4 11.00 | 0x13CF40 |
pub fn size(&self) -> NonZero<usize>
pub fn allocated_size(&self) -> usize
pub fn item_per_slab(&self) -> usize
pub fn recurse(&self) -> u32
pub fn flags(&self) -> UmaFlags